{% extends 'base.html' %}
{% block content %}
<form action="" method="post">{% csrf_token %}
    {{ form.as_p }}
	<input type="submit" value="Aktualizuj" class="btn btn-danger btn-xs"/>
	<a href="{% url 'appadmin' %}"  role="button" class="btn btn-success btn-xs">Powrót</a>
</form>
{% endblock %}